package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.CompanySaleMapper;
import com.ruoyi.system.domain.CompanySale;
import com.ruoyi.system.service.ICompanySaleService;
import com.ruoyi.common.core.text.Convert;

/**
 * 广告主销售Service业务层处理
 *
 * @author ruoyi
 * @date 2023-05-15
 */
@Service
public class CompanySaleServiceImpl implements ICompanySaleService
{
    @Autowired
    private CompanySaleMapper companySaleMapper;

    /**
     * 查询广告主销售
     *
     * @param id 广告主销售主键
     * @return 广告主销售
     */
    @Override
    public CompanySale selectCompanySaleById(Long id)
    {
        return companySaleMapper.selectCompanySaleById(id);
    }

    /**
     * 查询广告主销售列表
     *
     * @param companySale 广告主销售
     * @return 广告主销售
     */
    @Override
    public List<CompanySale> selectCompanySaleList(CompanySale companySale)
    {
        return companySaleMapper.selectCompanySaleList(companySale);
    }

    /**
     * 新增广告主销售
     *
     * @param companySale 广告主销售
     * @return 结果
     */
    @Override
    public int insertCompanySale(CompanySale companySale)
    {
        companySale.setCreateTime(DateUtils.getNowDate());
        return companySaleMapper.insertCompanySale(companySale);
    }

    /**
     * 修改广告主销售
     *
     * @param companySale 广告主销售
     * @return 结果
     */
    @Override
    public int updateCompanySale(CompanySale companySale)
    {
        companySale.setUpdateTime(DateUtils.getNowDate());
        return companySaleMapper.updateCompanySale(companySale);
    }

    /**
     * 批量删除广告主销售
     *
     * @param ids 需要删除的广告主销售主键
     * @return 结果
     */
    @Override
    public int deleteCompanySaleByIds(String ids)
    {
        return companySaleMapper.deleteCompanySaleByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除广告主销售信息
     *
     * @param id 广告主销售主键
     * @return 结果
     */
    @Override
    public int deleteCompanySaleById(Long id)
    {
        return companySaleMapper.deleteCompanySaleById(id);
    }
}
